package se.nekotronic.majtenta;

import java.util.LinkedList;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnTouchListener;

public class GraphicalView extends View implements OnClickListener, OnTouchListener {
	class Point {
		float x;
		float y;
		public Point(float x, float y) {
			this.x = x;
			this.y = y;
		}
	}

    private int width_pixels;
    private int height_pixels;
    
    private LinkedList<Point> points = new LinkedList<Point>();
    
	public GraphicalView(Context context) {
		super(context);
		// TODO Auto-generated constructor stub
	}

    @Override
        protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        width_pixels = w;
        height_pixels = h;
        this.setOnClickListener(this);
        this.setOnTouchListener(this);
    } // onSizeChanged

    public GraphicalView(Context context, AttributeSet attrs) {
        super(context, attrs);
    }
    
    private Paint p = new Paint();

    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        int w = width_pixels > 0 ? width_pixels : canvas.getHeight();
        int h = height_pixels > 0 ? height_pixels : canvas.getWidth();

        p.setColor(Color.WHITE);
        canvas.drawRect(0,  0, w, h, p);
        
        p.setColor(Color.RED);
        canvas.drawText("w = " + w + " (" + width_pixels + ")" +
                        ", h = " + h + " (" + height_pixels + ")",
                        20.0f, 20.0f, p);

        canvas.drawText("basen.oru.se/android",
                20.0f, h - 5.0f, p);

        p.setColor(Color.BLACK);

        for (Point point : points) {
        	canvas.drawCircle(point.x, point.y, 2.0f, p);
        }
    } // onDraw

	@Override
	public void onClick(View view) {
		Log.d("*****", "onClick(view = " + view + ")");
	}

	@Override
	public boolean onTouch(View view, MotionEvent event) {
		Log.d("*****", "onTouch(view = " + view + ", event = " + event + ")");
		return false;
	}		

	@Override
	public boolean onTouchEvent(MotionEvent event) {
		super.onTouchEvent(event);
		Log.d("*****", "onTouchEvent(event = " + event + ")");
		if (event.getAction() == MotionEvent.ACTION_DOWN)
			Log.d("--------", "Down");
		else if (event.getAction() == MotionEvent.ACTION_UP)
			Log.d("--------", "Up");
		else if (event.getAction() == MotionEvent.ACTION_MOVE)
			Log.d("--------", "Move");
		float x = event.getX();
		float y = event.getY();
		Log.d("--------", "x = " + x + ", y = " + y);
		
		points.add(new Point(x, y));
		this.invalidate();
		
		return true;
	} // onTouchEvent

	public void setPoints(String gamla_punkter) {
		String numbers[] = gamla_punkter.split(" ");
        int nr_points = numbers.length;
        for (int i = 0; i < nr_points / 2; ++i) {
        	float oldx = Float.parseFloat(numbers[2*i]);
        	float oldy = Float.parseFloat(numbers[2*i + 1]);
    		points.add(new Point(oldy, oldx)); // Note: New x = old y, and vice versa
   		}
	} // setPoints

	public String getPoints() {
		String result = "" + points.size();
        for (Point point : points) {
        	result += " " + point.x + " " + point.y;
        }
		return result;
	} // getPoints
}
